@@ -21,7 +21,7 @@ class InvoiceLine(metaclass=PoolMeta):
     secondary_unit = fields.Many2One(
         'product.uom', "Secondary Unit", ondelete='RESTRICT',
         domain=[
-            ('category', '=', Eval('product_secondary_uom_category')),
+            ('category', '=', Eval('product_secondary_uom_category', -1)),
             ],
         states={
             'invisible': ((Eval('type') != 'line')
@@ -40,7 +40,8 @@ class InvoiceLine(metaclass=PoolMeta):
 
     product_secondary_uom_category = fields.Function(
         fields.Many2One(
-            'product.uom.category', "Product Secondary UOM Category"),
+            'product.uom.category', "Product Secondary UoM Category",
+            help="The category of secondary Unit of Measure for the product."),
         'get_product_secondary_uom_category')
 
     @fields.depends('quantity', 'unit', 'secondary_unit', 'origin')
@@ -105,7 +106,8 @@ class InvoiceLine(metaclass=PoolMeta):
         self.on_change_secondary_unit_price()
 
     def get_product_secondary_uom_category(self, name):
-        return None
+        if isinstance(self.origin, self.__class__):
+            return self.origin.product_secondary_uom_category
 
     @classmethod
     def set_secondary(cls, lines, name, value):
@@ -113,8 +115,15 @@ class InvoiceLine(metaclass=PoolMeta):
 
     @property
     def secondary_uom_factor(self):
-        return None
+        if isinstance(self.origin, self.__class__):
+            return self.origin.secondary_uom_factor
 
     @property
     def secondary_uom_rate(self):
-        return None
+        if isinstance(self.origin, self.__class__):
+            return self.origin.secondary_uom_rate
+
+    def _credit(self):
+        line = super()._credit()
+        line.secondary_unit = self.secondary_unit
+        return line
